@@ -63,7 +63,7 @@ private:
     bool m_questionMixed;
 
     /** overrideing the paint event of FractionBaseWidget */
-    void paintEvent(QPaintEvent*);
+    void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
 };
 
 #endif
